@@ -4,5 +4,5 @@ VV.vgc <- function (obj, N=NA, ...)
   if (!attr(obj, "hasVariances")) stop("no variance data available for vocabulary growth curve")
   if (!missing(N)) stop("argument 'N' not allowed for object of class 'vgc'")
   
-  obj$VV
+  structure(obj$VV, names=obj$N)
 }
