@@ -2,5 +2,5 @@ V.vgc <- function (obj, ...)
 {
   if (! inherits(obj, "vgc")) stop("argument must be object of class 'vgc'")
 
-  obj$V
+  structure(obj$V, names=obj$N)
 }
